==> gst-plugins-bad0-0.10.23-x86_64-3gv.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libgstphotography-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstphotography-0.10.so.23.0.0 libgstphotography-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstphotography-0.10.so )
( cd usr/lib64 ; ln -sf libgstphotography-0.10.so.23.0.0 libgstphotography-0.10.so )
( cd usr/lib64 ; rm -rf libgstsignalprocessor-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstsignalprocessor-0.10.so.23.0.0 libgstsignalprocessor-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstsignalprocessor-0.10.so )
( cd usr/lib64 ; ln -sf libgstsignalprocessor-0.10.so.23.0.0 libgstsignalprocessor-0.10.so )
( cd usr/lib64 ; rm -rf libgstbasevideo-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstbasevideo-0.10.so.23.0.0 libgstbasevideo-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstbasevideo-0.10.so )
( cd usr/lib64 ; ln -sf libgstbasevideo-0.10.so.23.0.0 libgstbasevideo-0.10.so )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-0.10.so.23.0.0 libgstbasecamerabinsrc-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-0.10.so )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-0.10.so.23.0.0 libgstbasecamerabinsrc-0.10.so )
( cd usr/lib64 ; rm -rf libgstcodecparsers-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstcodecparsers-0.10.so.23.0.0 libgstcodecparsers-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstcodecparsers-0.10.so )
( cd usr/lib64 ; ln -sf libgstcodecparsers-0.10.so.23.0.0 libgstcodecparsers-0.10.so )
( cd usr/lib64 ; rm -rf libgstvdp-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstvdp-0.10.so.23.0.0 libgstvdp-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstvdp-0.10.so )
( cd usr/lib64 ; ln -sf libgstvdp-0.10.so.23.0.0 libgstvdp-0.10.so )

doinst () 
{ 
    if [ -x /usr/bin/glib-compile-schemas ]; then
        /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas > /dev/null 2>&1;
    fi
}
doinst

==> gst-plugins-bad-0.10.23-x86_64-2gv.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libgstphotography-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstphotography-0.10.so.23.0.0 libgstphotography-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstphotography-0.10.so )
( cd usr/lib64 ; ln -sf libgstphotography-0.10.so.23.0.0 libgstphotography-0.10.so )
( cd usr/lib64 ; rm -rf libgstsignalprocessor-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstsignalprocessor-0.10.so.23.0.0 libgstsignalprocessor-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstsignalprocessor-0.10.so )
( cd usr/lib64 ; ln -sf libgstsignalprocessor-0.10.so.23.0.0 libgstsignalprocessor-0.10.so )
( cd usr/lib64 ; rm -rf libgstbasevideo-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstbasevideo-0.10.so.23.0.0 libgstbasevideo-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstbasevideo-0.10.so )
( cd usr/lib64 ; ln -sf libgstbasevideo-0.10.so.23.0.0 libgstbasevideo-0.10.so )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-0.10.so.23.0.0 libgstbasecamerabinsrc-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-0.10.so )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-0.10.so.23.0.0 libgstbasecamerabinsrc-0.10.so )
( cd usr/lib64 ; rm -rf libgstcodecparsers-0.10.so.23 )
( cd usr/lib64 ; ln -sf libgstcodecparsers-0.10.so.23.0.0 libgstcodecparsers-0.10.so.23 )
( cd usr/lib64 ; rm -rf libgstcodecparsers-0.10.so )
( cd usr/lib64 ; ln -sf libgstcodecparsers-0.10.so.23.0.0 libgstcodecparsers-0.10.so )

doinst() {
# compile schemas
if [ -x /usr/bin/glib-compile-schemas ]; then
	/usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas > /dev/null 2>&1
fi
}
doinst
